pub struct RequestError {
pub status: u16,
pub reason: String,
pub message: Option<String>,
pub error: Option<SmartsheetError>,
}Expand description
RequestError is raised when the Smartsheet API responds back with a
non- “OK” response.
More specifically, this error is raised when the status code of a response is between 400 and 600, which indicates its either a client error or a server error.
Note
The error and message fields are mutually-exclusive; if we cannot
de-serialize error, the message will be populated instead with the
response data.
Fields
status: u16reason: Stringmessage: Option<String>error: Option<SmartsheetError>Implementations